@@ -7,9 +7,10 @@
 # Updated by Russ Housley for AlgorithmIdentifier opentype support.
 # Updated by Russ Housley for https://github.com/etingof/pyasn1-modules/pull/139.
 # Updated by Russ Housley to include the opentypemap manager.
+# Updated by CBonnell to populate the policyQualifierInfosMap.
 #
 # Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
-# Copyright (c) 2021, Vigil Security, LLC
+# Copyright (c) 2021-2022, Vigil Security, LLC
 # License: http://vigilsec.com/pyasn1-alt-modules-license.txt
 #
 # Internet X.509 Public Key Infrastructure Certificate and Certificate
@@ -1599,6 +1600,16 @@ _orAddressExtensionAttributesMapUpdate = {
 orAddressExtensionAttributesMap.update(_orAddressExtensionAttributesMapUpdate)
 
 
+# map of PolicyQualifierId -> Qualifier
+
+_policyQualifierInfosMapUpdate = {
+    id_qt_cps: CPSuri(),
+    id_qt_unotice: UserNotice(),
+}
+
+policyQualifierInfosMap.update(_policyQualifierInfosMapUpdate)
+
+
 # map of AttributeType -> AttributeValue
 
 _certificateAttributesMapUpdate = {
